==> 1.0.2.tar.gz: lib/src/themes/theme_provider.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';

class ThemeProvider with ChangeNotifier {
  ThemeProvider({
    required this.darkTheme,
    required this.lightTheme,
    bool? dark,
  }) {
    switchTheme(dark ?? _isDarkMode);
  }

  factory ThemeProvider.defaultThemes({Color? accentColor, Color? primaryColor, DividerThemeData? dividerTheme}) {
    ThemeData darkTheme = ThemeData(
      accentColor: accentColor,
      brightness: Brightness.dark,
      primaryColor: primaryColor,
      dividerTheme: dividerTheme,
    );

    ThemeData lightTheme = ThemeData(
      accentColor: accentColor,
      brightness: Brightness.light,
      primaryColor: primaryColor,
    );
    return ThemeProvider(darkTheme: darkTheme, lightTheme: lightTheme);
  }

  ThemeData darkTheme;
  ThemeData lightTheme;

  late ThemeMode _themeMode;

  ThemeData? get currentTheme => _themeMode == ThemeMode.dark ? darkTheme : lightTheme;

  ThemeMode get themeMode => _themeMode;

  bool get isDarkMode => _themeMode == ThemeMode.dark;

  void switchTheme(bool? dark) async {
    if (dark == null) {
      _themeMode = ThemeMode.system;
    } else {
      _themeMode = dark == true ? ThemeMode.dark : ThemeMode.light;
    }
    notifyListeners();
  }

  bool get _isDarkMode {
    var brightness = SchedulerBinding.instance?.window.platformBrightness;
    return brightness == Brightness.dark;
  }

  void changePrimaryColor(Color? color) {
    final newDarkTheme = darkTheme.copyWith(primaryColor: color);
    final newLightTheme = lightTheme.copyWith(primaryColor: color);
    darkTheme = newDarkTheme;
    lightTheme = newLightTheme;
    notifyListeners();
  }

  void changeAccentColor(Color? color) {
    final newDarkTheme = darkTheme.copyWith(accentColor: color);
    final newLightTheme = lightTheme.copyWith(accentColor: color);
    darkTheme = newDarkTheme;
    lightTheme = newLightTheme;
    notifyListeners();
  }
}

==> 4.0.0.tar.gz: lib/src/themes/theme_provider.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';

class ThemeProvider with ChangeNotifier {
  ThemeProvider({
    required this.darkTheme,
    required this.lightTheme,
    bool? dark,
    ThemeMode themeMode = ThemeMode.dark,
  }) {
    _themeMode = themeMode;
    // switchTheme(dark ?? _isDarkMode);
  }

  factory ThemeProvider.defaultThemes(
      {Color? accentColor, Color? primaryColor, DividerThemeData? dividerTheme, ThemeMode themeMode = ThemeMode.dark}) {
    ThemeData darkTheme = ThemeData(
      accentColor: accentColor,
      brightness: Brightness.dark,
      primaryColor: primaryColor,
      dividerTheme: dividerTheme,
    );

    ThemeData lightTheme = ThemeData(
      accentColor: accentColor,
      brightness: Brightness.light,
      primaryColor: primaryColor,
    );
    return ThemeProvider(darkTheme: darkTheme, lightTheme: lightTheme, themeMode: themeMode);
  }

  ThemeData darkTheme;
  ThemeData lightTheme;

  late ThemeMode _themeMode;

  ThemeData? get currentTheme => _themeMode == ThemeMode.dark ? darkTheme : lightTheme;

  ThemeMode get themeMode => _themeMode;

  bool get isDarkMode => _themeMode == ThemeMode.dark;

  void switchTheme(bool? dark) async {
    if (dark == null) {
      _themeMode = ThemeMode.system;
    } else {
      _themeMode = dark == true ? ThemeMode.dark : ThemeMode.light;
    }
    notifyListeners();
  }

  bool get _isDarkMode {
    var brightness = SchedulerBinding.instance?.window.platformBrightness;
    return brightness == Brightness.dark;
  }

  void changeThemeMode(ThemeMode value) {
    if (_themeMode == value) {
      return;
    }
    _themeMode = value;
    notifyListeners();
  }

  void changeBrightness(Brightness value) {
    final newThemeMode = value == Brightness.dark ? ThemeMode.dark : ThemeMode.light;
    if (_themeMode == newThemeMode) {
      return;
    }
    _themeMode = newThemeMode;
    notifyListeners();
  }

  void changePrimaryColor(Color? color) {
    final newDarkTheme = darkTheme.copyWith(primaryColor: color);
    final newLightTheme = lightTheme.copyWith(primaryColor: color);
    darkTheme = newDarkTheme;
    lightTheme = newLightTheme;
    notifyListeners();
  }

  void changeAccentColor(Color? color) {
    final newDarkTheme = darkTheme.copyWith(accentColor: color);
    final newLightTheme = lightTheme.copyWith(accentColor: color);
    darkTheme = newDarkTheme;
    lightTheme = newLightTheme;
    notifyListeners();
  }
}
